==> haskell-pandoc-types-1.20-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-types
version:              1.20
visibility:           public
id:                   pandoc-types-1.20-IXhHi9Hljjy4kxzaYe5wMW
key:                  pandoc-types-1.20-IXhHi9Hljjy4kxzaYe5wMW
license:              BSD-3-Clause
copyright:            (c) 2006-2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  474bd95bbde1103649a15b7d1340e29a
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Legacy.Builder
    Text.Pandoc.Legacy.Definition Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-8.8.3/site-local/pandoc-types-1.20
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pandoc-types-1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/pandoc-types-1.20
hs-libraries:         HSpandoc-types-1.20-IXhHi9Hljjy4kxzaYe5wMW
depends:
    QuickCheck-2.13.2-6fFQIFT0E4j6TGV1ji065T
    aeson-1.4.6.0-GeTJOGqZVuq2YsM7zVlr7H base-4.13.0.0
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 syb-0.7.1-HZot41yU46FEB2GjLEhNpM text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.20-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-types
version:              1.20
visibility:           public
id:                   pandoc-types-1.20-CVZuGjtSbi51JzMvebIjml
key:                  pandoc-types-1.20-CVZuGjtSbi51JzMvebIjml
license:              BSD-3-Clause
copyright:            (c) 2006-2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  7ec891bc7b89dcdb6b1ca7abfe17df14
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Legacy.Builder
    Text.Pandoc.Legacy.Definition Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-8.8.3/site-local/pandoc-types-1.20
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pandoc-types-1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/pandoc-types-1.20
hs-libraries:         HSpandoc-types-1.20-CVZuGjtSbi51JzMvebIjml
depends:
    QuickCheck-2.13.2-6162FC0NJtEaNoo7xqAu9
    aeson-1.4.7.0-6PzSaqxxzl7AIT9Pz5Kfsg base-4.13.0.0
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 syb-0.7.1-HZot41yU46FEB2GjLEhNpM text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
